@@ -206,6 +206,29 @@ class MemoryLeakTest(CoverageTest):
         if fails > 8:
             pytest.fail("RAM grew by %d" % (ram_growth))      # pragma: only failure
 
+    @pytest.mark.skipif(not testenv.C_TRACER, reason="Only the C tracer has refcounting issues")
+    # In fact, sysmon explicitly holds onto all code objects,
+    # so this will definitely fail with sysmon.
+    @pytest.mark.parametrize("branch", [False, True])
+    def test_eval_codeobject_leak(self, branch: bool) -> None:
+        # https://github.com/nedbat/coveragepy/issues/1924
+        code = """\
+            for i in range(10_000):
+                r = eval("'a' + '1'")
+                assert r == 'a1'
+            """
+        # Looking for leaks is hard.  We consider the leak fixed if at least
+        # one of our loops only increased the footprint by a small amount.
+        base = osinfo.process_ram()
+        deltas = []
+        for _ in range(10):
+            self.check_coverage(code, [1, 2, 3], "", branch=branch)
+            now = osinfo.process_ram()
+            deltas.append(now - base)
+            print(f"Mem delta: {(now - base)//1024}")
+            base = now
+        assert any(d < 50 * 1024 for d in deltas)
+
 
 class MemoryFumblingTest(CoverageTest):
     """Test that we properly manage the None refcount."""
