@@ -5,6 +5,7 @@
 
 from __future__ import annotations
 
+import ast
 import re
 import textwrap
 from unittest import mock
@@ -13,7 +14,7 @@ import pytest
 
 from coverage import env
 from coverage.exceptions import NoSource, NotPython
-from coverage.parser import PythonParser
+from coverage.parser import PythonParser, is_constant_test_expr
 
 from tests.coveragetest import CoverageTest
 from tests.helpers import arcz_to_arcs
@@ -1101,6 +1102,24 @@ class MatchCaseMissingArcDescriptionTest(PythonParserTestBase):
         # 4-6 isn't a possible arc, so the description is generic.
         assert parser.missing_arc_description(4, 6) == "line 4 didn't jump to line 6"
 
+    def test_missing_arc_descriptions_bug1775(self) -> None:
+        # Bug: the `if x == 2:` line was marked partial with a message of:
+        # line 6 didn't return from function 'func', because the return on line 4 wasn't executed
+        # At some point it changed to "didn't jump to the function exit," which
+        # is close enough. These situations are hard to describe precisely.
+        parser = self.parse_text("""\
+            def func():
+                x = 2
+                try:
+                    return 4
+                finally:
+                    if x == 2:  # line 6
+                        print("x is 2")
+
+            func()
+            """)
+        assert parser.missing_arc_description(6, -1) == "line 6 didn't jump to the function exit"
+
 
 class ParserFileTest(CoverageTest):
     """Tests for coverage.py's code parsing from files."""
@@ -1174,3 +1193,24 @@ class ParserFileTest(CoverageTest):
         with pytest.raises(NoSource, match=re.escape(msg)):
             with mock.patch("coverage.python.read_python_source", side_effect=OSError("Fake!")):
                 PythonParser(filename="cant-read.py")
+
+
+@pytest.mark.parametrize(
+    ["expr", "is_constant"],
+    [
+        ("True", True),
+        ("False", True),
+        ("__debug__", True),
+        ("not __debug__", True),
+        ("not(__debug__)", True),
+        ("-__debug__", False),
+        ("__debug__ or True", True),
+        ("__debug__ + True", False),
+        ("x", False),
+        ("__debug__ or debug", False),
+    ]
+)
+def test_is_constant_test_expr(expr: str, is_constant: bool) -> None:
+    node = ast.parse(expr, mode="eval").body
+    print(ast.dump(node, indent=4))
+    assert is_constant_test_expr(node) == is_constant
